summaryrefslogtreecommitdiff
path: root/source3/auth
diff options
context:
space:
mode:
authorTim Potter <tpot@samba.org>2002-05-28 23:22:05 +0000
committerTim Potter <tpot@samba.org>2002-05-28 23:22:05 +0000
commit84a9a6a1be123ad31d21e743ef5b37f58122333a (patch)
tree03293f17d1358d485cf42b88845eb5ac0e03c0c1 /source3/auth
parent2bba2d15c696c64c9766dd6b03f7b3c1b246bca5 (diff)
downloadsamba-84a9a6a1be123ad31d21e743ef5b37f58122333a.tar.gz
samba-84a9a6a1be123ad31d21e743ef5b37f58122333a.tar.bz2
samba-84a9a6a1be123ad31d21e743ef5b37f58122333a.zip
Spelling fixes.
(This used to be commit 3d0f4acad2f0c57d0a255e90e5f674ba582251e2)
Diffstat (limited to 'source3/auth')
-rw-r--r--source3/auth/auth.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/source3/auth/auth.c b/source3/auth/auth.c
index 55695fa9c2..1919a69df2 100644
--- a/source3/auth/auth.c
+++ b/source3/auth/auth.c
@@ -23,7 +23,7 @@
#undef DBGC_CLASS
#define DBGC_CLASS DBGC_AUTH
/** List of various built-in authenticaion modules */
const struct auth_init_function_entry builtin_auth_init_functions[] = {
{ "guest", auth_init_guest },
@@ -43,7 +43,7 @@ const struct auth_init_function_entry builtin_auth_init_functions[] = {
};
/****************************************************************************
- Try to get a challenge out of the various authenticaion modules.
+ Try to get a challenge out of the various authentication modules.
Returns a const char of length 8 bytes.
****************************************************************************/
@@ -68,7 +68,7 @@ static const uint8 *get_ntlm_challenge(struct auth_context *auth_context)
DEBUG(5, ("auth_get_challenge: getting challenge from module %s\n", auth_method->name));
if (challenge_set_by != NULL) {
- DEBUG(1, ("auth_get_challenge: CONFIGURATION ERROR: authenticaion method %s has already specified a challenge. Challenge by %s ignored.\n",
+ DEBUG(1, ("auth_get_challenge: CONFIGURATION ERROR: authentication method %s has already specified a challenge. Challenge by %s ignored.\n",
challenge_set_by, auth_method->name));
continue;
}
@@ -80,7 +80,7 @@ static const uint8 *get_ntlm_challenge(struct auth_context *auth_context)
challenge = auth_method->get_chal(auth_context, &auth_method->private_data, mem_ctx);
if (!challenge.length) {
- DEBUG(3, ("auth_get_challenge: getting challenge from authenticaion method %s FAILED.\n",
+ DEBUG(3, ("auth_get_challenge: getting challenge from authentication method %s FAILED.\n",
auth_method->name));
} else {
DEBUG(5, ("auth_get_challenge: sucessfully got challenge from module %s\n", auth_method->name));
@@ -164,7 +164,7 @@ static BOOL check_domain_match(const char *user, const char *domain)
* filled in, either at creation or by calling the challenge geneation
* function auth_get_challenge().
*
* @param server_info If successful, contains information about the authenticaion,
* including a SAM_ACCOUNT struct describing the user.
*
* @return An NTSTATUS with NT_STATUS_OK or an appropriate error.
@@ -257,7 +257,7 @@ static NTSTATUS check_ntlm_password(const struct auth_context *auth_context,
if (NT_STATUS_IS_OK(nt_status)) {
DEBUG((*server_info)->guest ? 5 : 2,
- ("check_password: %sauthenticaion for user [%s] -> [%s] -> [%s] suceeded\n",
+ ("check_password: %sauthentication for user [%s] -> [%s] -> [%s] suceeded\n",
(*server_info)->guest ? "guest " : "",
user_info->smb_name.str,
user_info->internal_username.str,
@@ -266,7 +266,7 @@ static NTSTATUS check_ntlm_password(const struct auth_context *auth_context,
}
if (!NT_STATUS_IS_OK(nt_status)) {
- DEBUG(2, ("check_password: Authenticaion for user [%s] -> [%s] FAILED with error %s\n",
+ DEBUG(2, ("check_password: Authentication for user [%s] -> [%s] FAILED with error %s\n",
user_info->smb_name.str, user_info->internal_username.str,
nt_errstr(nt_status)));
ZERO_STRUCTP(server_info);
@@ -23,7 +23,7 @@
#undef DBGC_CLASS
#define DBGC_CLASS DBGC_AUTH
-/** List of various built-in authenticaion modules */
+/** List of various built-in authentication modules */
const struct auth_init_function_entry builtin_auth_init_functions[] = {
{ "guest", auth_init_guest },
@@ -164,7 +164,7 @@ static BOOL check_domain_match(const char *user, const char *domain)
* function auth_get_challenge().
*
- * @param server_info If successful, contains information about the authenticaion,
+ * @param server_info If successful, contains information about the authentication,
* including a SAM_ACCOUNT struct describing the user.
*